pywr.parameters.AnnualHarmonicSeriesParameter — Pywr 0.5dev documentation

# pywr.parameters.AnnualHarmonicSeriesParameter

class `pywr.parameters.` `AnnualHarmonicSeriesParameter`

  A Parameter which returns the value from an annual harmonic series

  This Parameter comprises a series N cosine function with a period of 365
    days. The calculation is performed using the Julien day of the year minus 1 This causes a small discontinuity in non-leap years.
  \[f(t) = A + \sum_{n=1}^N A_n\cdot \cos((2\pi nt)/365+\phi_n)\]

  Parameters: | mean : float Mean value for the series (i.e. the position of zeroth harmonic) amplitudes : array_like The amplitudes for the N harmonic cosine functions. Must be the same length as phases. phases : array_like The phase shift of the N harmonic cosine functions. Must be the same length as amplitudes.

  `__init__`($self, /, *args, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `after` |
  `before` |
  `finish` |
  `get_all_values` |
  `get_double_lower_bounds` |
  `get_double_upper_bounds` |
  `get_double_variables` |
  `get_integer_lower_bounds` |
  `get_integer_upper_bounds` |
  `get_integer_variables` |
  `get_value` |
  `load` |
  `lower_bounds` |
  `register` |
  `reset` |
  `set_double_variables` |
  `set_integer_variables` |
  `setup` |
  `unregister` |
  `update` |
  `upper_bounds` |
  `value` |

  Attributes

  `amplitudes` |
  `children` |
  `comment` |
  `double_size` |
  `integer_size` |
  `is_variable` |
  `mean` |
  `model` |
  `name` |
  `parents` |
  `phases` |
  `size` |